/**
   Randomly delete line segments from each model.

   This class is a "pipeline stage" because it
   extends the PipelineStage abstract class, which
   consists of a single method, processModel().
*/
import java.util.Random;

public class DropShader extends PipelineStage
{
   public double probability;
   private Random generator;

   /**
      This constructor initializes this shader's
      reference to the SceneRender object that
      contains it. This constructor also sets
      a parameter needed by this shader.
   */
   public DropShader(double probability, SceneRender sceneRender)
   {
      super(sceneRender);

      this.probability = probability;

      generator = new Random();
   }


   /**
      Randomly drop line segments from this model's list of line segments.
   */
   public Model processModel(Model model)
   {
      Model newModel = new Model(model); // copy everything but the line segments

      for (LineSegment ls : model.lineSegmentList)
      {
         double r = generator.nextDouble();
         if (r >= probability)
            newModel.addLineSegment(ls);
      }

      return newModel;
   }
}