/*
   Use this program to experiment with two-dimensional transformations.

   Try mixing the ordering of rotations, translations, and scallings.
*/
import java.io.File;
import java.awt.Color;

public class TransformationTester
{
   public static void main(String[] args)
   {
      // Create several 2D Model objects.
      Model m1 = new GRSModel(new File("resources/grs/bronto.grs"));
      Model m2 = new GRSModel(new File("resources/grs/usa.grs"));
      Model m3 = new GRSModel(new File("resources/grs/rex.grs"));
      Model m4 = new GRSModel(new File("resources/grs/vinci.grs"));
      Model m5 = new SimpleModel();

      // Pick a model from the above models.
      Model m = m1;

      // Set the model's color.
      m.setColor(Color.black);

      // Create the Scene object that we shall render
      Scene scene = new Scene();

      // Add a model to the Scene.
      scene.modelList.add(m);

      // Create a Camera object.
      Camera camera = new Camera();

      // Give the Camera a view matrix.
      camera.view2Identity();

      // Set up the camera's view frustum.
      double left   = -3.0;
      double right  =  3.0;
      double top    =  3.0;
      double bottom = -3.0;
      double near   =  1.0;
      double far    =  20.0;
      camera.projOrtho(left, right, bottom, top, near, far);

      // Set up the camera's location and orientation.
      double eyex=0,    eyey=0,    eyez=8;
      double centerx=0, centery=0, centerz=0;
      double upx=0,     upy=1,     upz=0;
      camera.viewLookAt(eyex,    eyey,    eyez,
                        centerx, centery, centerz,
                        upx,     upy,     upz);

      // Add the Camera to the Scene.
      scene.setCamera(camera);

      // Create a set of x and y axes.
      Model axes = new Axes2DModel(left, right, bottom, top, 24, 24);
      scene.modelList.add(axes);

      // Create a framebuffer to render our scene into.
      int vp_width  = 512;
      int vp_height = 512;
      FrameBuffer fb = new FrameBuffer(vp_width, vp_height);
      // Give the framebuffer a nice background color.
      fb.clearFB(java.awt.Color.lightGray);

      // Create a default rendering pipeline.
      SceneRender renderer = new SceneRender();


      for (int i = 0; i <= 36; i++)
      {
         m.model2Identity();
         m.modelRotate(10*i, 0, 0, 1);
         m.modelTranslate(1, 0, 0);
         // Render again.
         fb.clearFB(java.awt.Color.lightGray);
         renderer.renderScene(scene, fb);
         fb.dumpFB2File(String.format("PPM_TransformationTester_Frame%02d.ppm", i));
      }
   }
}