/**
   A LineSegment object has two Vertex objects that represent the endpoints of the line segment.
*/
import java.awt.Color;

public class LineSegment
{
   public Vertex[] v = new Vertex[2]; // the vertices of this line segment

   public LineSegment()
   {
      v[0] = null;
      v[1] = null;
   }


   /**
      Create a LineSegment object whose vertices are copies of the two given Vertex objects.
   */
   public LineSegment(Vertex v0, Vertex v1)
   {
      v[0] = new Vertex(v0);  // make copies of each Vertex!
      v[1] = new Vertex(v1);
   }


   /**
      Create a LineSegment object whose vertices are copies of the two vertices from the given LineSegment object.
   */
   public LineSegment(LineSegment ls) // a "copy constructor"
   {
      v[0] = new Vertex(ls.v[0]);  // make copies of each Vertex!
      v[1] = new Vertex(ls.v[1]);
   }


   /**
      Give this line segment a uniform color.
   */
   public void setColor(Color c)
   {
      v[0].setColor(c);
      v[1].setColor(c);
   }

   /**
      Give this line segment a uniform, but randomly chosen, color.
   */
   public void setColorRandom()
   {
      v[0].setColorRandom();
      v[1].setColor(v[0].getColor());
   }


   /**
      For debugging.
   */
   public String toString()
   {
      String result = "Line Segment:\n";
      result += v[0].toString();
      result += v[1].toString();
      return result;
   }

   /**
      For debugging. What this method prints out
      depends on the value of the parameter vertexFields.

      The value of vertexFields is treated as a bit field.
      The bits have the following meanings.
        1 => print vertex coordinates
        2 => print r g b values
   */
   public String toString(int vertexFields)
   {
      String result = "Line Segment:\n";
      result += v[0].toString(vertexFields);
      result += v[1].toString(vertexFields);
      return result;
   }
}