/**
   Convert vertices from model coordinates to world coordinates.

   For each Model in a Scene, walk the Model's list of LineSegment objects.
   For each Vertex object in each LineSgement object, use the Model's model
   matrix to transform the Vertex object from model coordinates to world
   coordinates.
*/

public class P1_Model2World extends PipelineStage
{
   /**
      This constructor initializes this object's
      reference to the SceneRender object that
      contains it. This gives this stage access
      to addditional information that might be
      needed to process the Models passed to the
      processModel() method.
   */
   public P1_Model2World(SceneRender sceneRender)
   {
      super(sceneRender);
   }


   /**
      For each line segment in the model, transform each
      vertex from model coordinates to world coordinates.
   */
   public Model processModel(Model model)
   {
      Matrix modelMatrix = model.modelMatrix;

      // Transform each line segment in the model's line segment list.
      for (LineSegment ls : model.lineSegmentList)
      {
         ls.v[0] = modelMatrix.times(ls.v[0]); // transform each vertex in the line segment
         ls.v[1] = modelMatrix.times(ls.v[1]);
      }
      return model;
   }
}