/**
   k   number of lines of longitude
   n+2 number of lines of latitude (there is always at least two)

   r   radius of the cylinder
   h   height of the cylinder
*/

public class CylinderModel extends Model
{
   public CylinderModel(int k, int n, double radius, double h)
   {
      super();

      // Create the cylinder's geometry.

      // An array of vertices to be used to create line segments.
      Vertex[][] v = new Vertex[n+2][k];

      // Create all the vertices along the cylinder wall.
      for (int j = 0; j < k; j++)
      {
         double c = Math.cos(j*(2.0*Math.PI)/k);
         double s = Math.sin(j*(2.0*Math.PI)/k);
         for (int i = 0; i <= n+1; i++)
         {
            v[i][j] = new Vertex( radius*c, h-i*((2.0*h)/(n+1)), radius*s );
         }
      }
      // Vertex at the center of the top.
      Vertex topCenter = new Vertex(0.0, h, 0.0);
      // Vertex at the center of the bottom.
      Vertex bottomCenter = new Vertex(0.0, -h, 0.0);


      // Create all the horizontal circles of latitude around the cylinder wall.
      LineSegment ls;
      for (int i = 0; i <= n+1; i++)
      {
         for (int j = 0; j < k-1; j++)
         {
            ls = new LineSegment( v[i][j], v[i][j+1] );
            this.addLineSegment( ls );
         }
         ls = new LineSegment( v[i][k-1], v[i][0] );
         this.addLineSegment( ls );
      }

      // Create the vertical half-rectangles of longitude from the north to the south pole.
      for (int j = 0; j < k; j++)
      {
         // Create the triangle fan at the top.
         ls = new LineSegment( topCenter, v[0][j] );
         this.addLineSegment( ls );

         // Create the vertical line from the top to the bottom.
         ls = new LineSegment( v[0][j], v[n+1][j] );
         this.addLineSegment( ls );

         // Create the triangle fan at the bottom.
         ls = new LineSegment( v[n+1][j], bottomCenter );
         this.addLineSegment( ls );
      }
   }
}//CylinderModel