/**
   k   number of lines of longitude
   n+1 number of lines of latitude (there is always at least one)

   r radius of the sphere

*/

public class SphereModel extends Model
{
   public SphereModel(int k, int n, double radius)
   {
      super();

      // Create the sphere's geometry.

      // An array of vertices to be used to create line segments.
      Vertex[][] v = new Vertex[n+1][k];

      // Create all the vertices.
      for (int j = 0; j < k; j++)
      {
         double c1 = Math.cos(j*(2.0*Math.PI)/k);
         double s1 = Math.sin(j*(2.0*Math.PI)/k);
         for (int i = 0; i <= n; i++)
         {
            double c2 = Math.cos((i+1)*Math.PI/(n+2));
            double s2 = Math.sin((i+1)*Math.PI/(n+2));
            v[i][j] = new Vertex(radius*s2*c1,
                                 radius*c2,
                                 radius*s2*s1);
         }
      }
      // Vertex at the center of the top.
      Vertex    topPole = new Vertex(0.0,  radius, 0.0);
      // Vertex at the center of the bottom.
      Vertex bottomPole = new Vertex(0.0, -radius, 0.0);


      // Create all the horizontal circles of latitude around the sphere.
      LineSegment ls;
      for (int i = 0; i <= n; i++)
      {
         for (int j = 0; j < k-1; j++)
         {
            ls = new LineSegment( v[i][j], v[i][j+1] );
            this.addLineSegment( ls );
         }
         ls = new LineSegment( v[i][k-1], v[i][0] );
         this.addLineSegment( ls );
      }

      // Create the vertical half-circles of longitude from the north to the south pole.
      for (int j = 0; j < k; j++)
      {
         // Create the triangle fan at the top.
         ls = new LineSegment( topPole, v[0][j] );
         this.addLineSegment( ls );

         // Create the circular arc from the top to the bottom.triangle fans
         for (int i = 0; i < n; i++)
         {
            ls = new LineSegment( v[i][j], v[i+1][j] );
            this.addLineSegment( ls );
         }

         // Create the triangle fan at the bottom.
         ls = new LineSegment( v[n][j], bottomPole );
         this.addLineSegment( ls );
      }
   }
}//SphereModel